@@ -468,6 +468,10 @@ module Extension : sig
 
   (** [pp ppf ext_map] pretty-prints the extension map. *)
   val pp : t Fmt.t
+
+  (** [pp' custom ppf ext_map] pretty-prints the extension map using [custom]
+      to print [Unsupported _] extensions. *)
+  val pp' : (Asn.oid * string) Fmt.t -> t Fmt.t
 end
 
 (** X509v3 certificate *)
@@ -490,6 +494,10 @@ module Certificate : sig
   (** [pp ppf cert] pretty-prints the certificate. *)
   val pp : t Fmt.t
 
+  (** [pp' pp_custom_extensions ppf cert] pretty-prints the certificate using
+      [pp_custom_extensions] for [Extension.Unsupported _] extension. *)
+  val pp' : (Asn.oid * string) Fmt.t -> t Fmt.t
+
   (** {1 Encoding and decoding in ASN.1 DER and PEM format} *)
 
   (** [decode_der octets] is [certificate], the ASN.1 decoded [certificate]
@@ -563,7 +571,10 @@ module Certificate : sig
       the [certificate]. *)
   val issuer : t -> Distinguished_name.t
 
-  (** [serial certificate] is [sn], the serial number of the [certificate]. *)
+  (** [serial certificate] is [sn], the serial number of the [certificate].
+      A serial is a positive number of at most 20 octets. 0 is supported. A
+      negative serial number is supported when decoding a certificate, but when
+      encoding, an octet of 0 is prepended making it positive. *)
   val serial : t -> string
 
   (** [validity certificate] is [from, until], the validity of the certificate. *)
@@ -1016,7 +1027,7 @@ module Authenticator : sig
       that uses the given [time] and [fingerprint] to verify the first
       element of the certificate chain, using
       {!Validation.trust_cert_fingerprint}.  Note that
-      {{!server_key_fingerprint}public key pinning} has
+      {{!key_fingerprint}public key pinning} has
       {{:https://www.imperialviolet.org/2011/05/04/pinning.html} advantages}
       over certificate pinning. *)
   val cert_fingerprint : time:(unit -> Ptime.t option) ->
